@@ -25,7 +25,7 @@ import numpy as np
 """
 
 FRIGIDUM_PATH = os.path.dirname( frigidum.__file__ )
-DATA_PATH = FRIGIDUM_PATH + '/data/'
+DATA_PATH = FRIGIDUM_PATH + '/data_files/'
 
 ks_10000_0_path = DATA_PATH + 'ks_10000_0'
 
