@@ -30,7 +30,7 @@ import numpy as np
 
 
 FRIGIDUM_PATH = os.path.dirname( frigidum.__file__ )
-DATA_PATH = FRIGIDUM_PATH + '/data/'
+DATA_PATH = FRIGIDUM_PATH + '/data_files/'
 
 """
 	REGEX taken from https://www.regular-expressions.info/floatingpoint.html
